<?php

namespace Drupal\menu_tree_compare\Form;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManager;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Menu\MenuLinkManagerInterface;
use Drupal\Core\Menu\MenuLinkTreeInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form controller for menu choice form.
 *
 * @internal
 */
class MenuChoiceForm extends FormBase implements ContainerInjectionInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManager
   */
  protected $entityTypeManager;

  public function __construct(EntityTypeManager $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'menu_choice_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $menu_options = [];
    /** @var \Drupal\system\Entity\Menu $menu */
    foreach($this->entityTypeManager->getStorage('menu')->loadMultiple() as $menu) {
      $menu_options[$menu->id()] = $menu->label();
    }

    $form['from'] = [
      '#type' => 'select',
      '#title' => t('Menu to compare - Left'),
      '#options' => $menu_options,
    ];

    $form['to'] = [
      '#type' => 'select',
      '#title' => t('Menu to compare - Right'),
      '#options' => $menu_options,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => 'Compare',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $route_parameters = [
      'from' => $form_state->getValue('from'),
      'to' => $form_state->getValue('to'),
    ];
    $form_state->setRedirect('menu_tree_compare.compare', $route_parameters, []);
  }

}
